summaryrefslogtreecommitdiff
path: root/bitbake/lib/bb/fetch/git.py
diff options
context:
space:
mode:
Diffstat (limited to 'bitbake/lib/bb/fetch/git.py')
-rw-r--r--bitbake/lib/bb/fetch/git.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/bitbake/lib/bb/fetch/git.py b/bitbake/lib/bb/fetch/git.py
index c81193774..911c5e437 100644
--- a/bitbake/lib/bb/fetch/git.py
+++ b/bitbake/lib/bb/fetch/git.py
@@ -145,12 +145,12 @@ class Git(Fetch):
def _build_revision(self, url, ud, d):
return ud.tag
- def _want_sortable_revision(self, url, ud, d):
+ def _sortable_revision_valid(self, url, ud, d):
return bb.data.getVar("BB_GIT_CLONE_FOR_SRCREV", d, True) or False
- def _sortable_revision_disabled(self, url, ud, d):
+ def _sortable_revision(self, url, ud, d):
"""
This is only called when _want_sortable_revision called true
We will have to get the updated revision.
"""
@@ -145,12 +145,12 @@ class Git(Fetch):
"""
- This is only called when _want_sortable_revision called true
+ This is only called when _sortable_revision_valid called true
We will have to get the updated revision.
"""